@@ -38,7 +38,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 
 #include "gdict-source.h"
 #include "gdict-client-context.h"
